pub fn render(
recording: RecordingStatus,
projection: RecordingProjection,
) -> RecordingViewExpand description
Adapts one Audio Ingress status and its matching History Handoff projection.
pub fn render(
recording: RecordingStatus,
projection: RecordingProjection,
) -> RecordingViewAdapts one Audio Ingress status and its matching History Handoff projection.